<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// Fichier source, a modifier dans https://git.spip.net/spip/statistiques.git

return [

	// S
	'stats_description' => 'Statistiques de SPIP',
	'stats_nom' => 'Statistiques',
	'stats_slogan' => 'Gestion des statistiques dans SPIP',
];
